# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.14
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CSPSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'mode': 'str',
        'directives': 'list[CSPDirective]'
    }

    attribute_map = {
        'enabled': 'enabled',
        'mode': 'mode',
        'directives': 'directives'
    }

    def __init__(self, enabled=None, mode=None, directives=None, local_vars_configuration=None):  # noqa: E501
        """CSPSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._mode = None
        self._directives = None
        self.discriminator = None

        self.enabled = enabled
        self.mode = mode
        self.directives = directives

    @property
    def enabled(self):
        """Gets the enabled of this CSPSettings.  # noqa: E501

        Whether or not to apply CSP. If disabled, the system will not set the Content-Security-Policy header; any CSP headers added by the application will be passed through unchanged.   # noqa: E501

        :return: The enabled of this CSPSettings.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CSPSettings.

        Whether or not to apply CSP. If disabled, the system will not set the Content-Security-Policy header; any CSP headers added by the application will be passed through unchanged.   # noqa: E501

        :param enabled: The enabled of this CSPSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def mode(self):
        """Gets the mode of this CSPSettings.  # noqa: E501

        Mode configures how the content security policy is enforced, if at all. Its possible values mean the following:   - enforce: Actively enforce the policy. Requests which fail the policy will be blocked.     If a report uri is configured for the policy, reports will be sent to it.   - reportonly: Any requests failing the policy generate reports. They are not blocked.   - disabled: the policy is disabled. Requests which would normally fail are neither blocked     nor reported on.   # noqa: E501

        :return: The mode of this CSPSettings.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this CSPSettings.

        Mode configures how the content security policy is enforced, if at all. Its possible values mean the following:   - enforce: Actively enforce the policy. Requests which fail the policy will be blocked.     If a report uri is configured for the policy, reports will be sent to it.   - reportonly: Any requests failing the policy generate reports. They are not blocked.   - disabled: the policy is disabled. Requests which would normally fail are neither blocked     nor reported on.   # noqa: E501

        :param mode: The mode of this CSPSettings.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and mode is None:  # noqa: E501
            raise ValueError("Invalid value for `mode`, must not be `None`")  # noqa: E501
        allowed_values = ["enforce", "reportonly", "disabled"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}"  # noqa: E501
                .format(mode, allowed_values)
            )

        self._mode = mode

    @property
    def directives(self):
        """Gets the directives of this CSPSettings.  # noqa: E501

        The directives which make up the policy. The system merges each directive into a single header by separating them with the `;` character. Duplicate directives will be merged with later directives in the array being appended to earlier ones.   # noqa: E501

        :return: The directives of this CSPSettings.  # noqa: E501
        :rtype: list[CSPDirective]
        """
        return self._directives

    @directives.setter
    def directives(self, directives):
        """Sets the directives of this CSPSettings.

        The directives which make up the policy. The system merges each directive into a single header by separating them with the `;` character. Duplicate directives will be merged with later directives in the array being appended to earlier ones.   # noqa: E501

        :param directives: The directives of this CSPSettings.  # noqa: E501
        :type: list[CSPDirective]
        """
        if self.local_vars_configuration.client_side_validation and directives is None:  # noqa: E501
            raise ValueError("Invalid value for `directives`, must not be `None`")  # noqa: E501

        self._directives = directives

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CSPSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CSPSettings):
            return True

        return self.to_dict() != other.to_dict()
